function HX = HX_curves_upward_fast(    hotst  , hstfrac , Tcsh , Thlim , ...
                                        coldst , cstfrac , Tcsc , Tclim , ...
                                        dTmin  , minadv  , nsteps )
% Calculates HX from T vs. q stream curves, only upwards, and fast
% Arguments: hotst,coldst    = streams matrix, 1st column T [K], 2nd column qs [e.g.,kW]
%                             starting at q=0 and q-sorted; qs > 0: cold , qs < 0: hot .
%            hstfrac,cstfrac = flowrate fraction of stream involved in this HX. []

%            Tcsh,Tcsc       = HX cold side stream Ts.   [K]
%            Thlim , Tclim   = Hot side stream T limits. [K]
%            dTmin           = Minimun allowed T approach between streams.
%                              If reached calculation is terminated. [K]
%            minadv          = minimum advance, first step. [kW]
%                              If <= 0, not used.
%                              (this is to terminate no heat exchange conditions early.)
%            nsteps          = number of steps to be calculated []
% Returns  : HX = matrix containing ... 
%            Tcsh    Thsh    = HX cold side , hot side hot  stream Ts [K]
%            Tcsc    Thsc    = HX cold side , hot side cold stream Ts [K]
%            duty    dTln    = extreme duty [kW]  , log mean of extreme T differences [K]
%            cstfrac hstfrac = cold, hot stream fraction involved in this HX. []
%            dTcs    dThs    = T differences in the cold, hot side [K]
%            mindT   maxdT   = Minimum and maximum T difference [K]

% Copyright (c) Fidel Mato & UVa 2018
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Heat integration, Heat exchanger

% [Note: kW are used as an alias for any thermal flow unit.]

Ths      = hotst(  : , 1 )         ;                       % [K]
Hhs      = hotst(  : , 2 )*hstfrac ;                       % [kW]
Tcs      = coldst( : , 1 )         ;                       % [K]
Hcs      = coldst( : , 2 )*cstfrac ;                       % [kW]

Hcsh     = interp1( Ths , Hhs , Tcsh  ) ;                  % [kW]
Hhlim    = interp1( Ths , Hhs , Thlim ) ;                  % [kW]
Hcsc     = interp1( Tcs , Hcs , Tcsc  ) ;                  % [kW]
Hclim    = interp1( Tcs , Hcs , Tclim ) ;                  % [kW]

if( Hhlim - Hcsh >= Hclim - Hcsc )
    H1 = Hcsc ;  H2 = Hclim ; incH = ( Hclim - Hcsc )/nsteps ;
else
%    H1 = Hcsh ;  H2 = Hhlim ; incH = -( Hcsh - Hhlim )/nsteps ;
    H1 = Hcsh ;  H2 = Hhlim ; incH = ( Hhlim - Hcsh )/nsteps ;
end

%if( incH <= 0 )
if( incH < 0 )
    error( 'incH <= 0' ) ;
end

%duties = []    ;
%Tcs = []    ;
%Ths  = []    ;
mindT  = 1e3   ; % [K] init
maxdT  = 0     ; % [K] init
Hs     = [ H1 : incH : H2 ] ;                              % [kW]
if( minadv > 0 )
    Hs     = [ Hs( 1 ) ( H1 + minadv ) Hs( 2 : end ) ] ;   % [kW] inserting minadv
end
for( H = Hs )
    duty = H - H1                             ;            % [kW]
    Th   = interp1( Hhs , Ths , Hcsh + duty ) ;            % [K]
    Tc   = interp1( Hcs , Tcs , Hcsc + duty ) ;            % [K]
    dT   = Th - Tc                            ;            % [K]
    %fprintf( '%8.3f %8.3f %10.2f %6.2f\n' , Th , Tc , duty , dT ); % DEBUG
    if( dT < dTmin && abs( dT - dTmin ) > 1e-8 )
        break ;
    end    
%    duties = [duties ; duty] ; Tcs = [Tcs ; Tc] ; Ths = [Ths ; Th] ;
    if( dT < mindT ) mindT = dT ; end
    if( dT > maxdT ) maxdT = dT ; end
end
Thsh     = Th ;                                            % [K]
Thsc     = Tc ;                                            % [K]


% ------------------------------------------------------------------------------ Returning
% Returns  : HX = matrix containing ... 
%            Tcsh    Thsh    = HX cold side , hot side hot  stream Ts [K]
%            Tcsc    Thsc    = HX cold side , hot side cold stream Ts [K]
%            duty    dTln    = extreme duty [kW]  , log mean of extreme T differences [K]
%            cstfrac hstfrac = cold, hot stream fraction involved in this HX. []
%            dTcs    dThs    = T differences in the cold, hot side [K]
%            mindT   maxdT   = Minimum and maximum T difference [K]

dTcs     = Tcsh - Tcsc ;                                   % [K]
dThs     = Thsh - Thsc ;                                   % [K]
if( dTcs ~= dThs )
    dTln = ( dTcs - dThs )/log( dTcs/dThs ) ;              % [K]
else
    dTln = dTcs ;                                          % [K]
end
HX       = ...
  [ Tcsh    Thsh                                           % [K,K]
    Tcsc    Thsc                                           % [K,K]
    duty    dTln                                           % [kW,K]
    cstfrac hstfrac                                        % [,]
    dTcs    dThs                                           % [K,K]
    mindT   maxdT  ] ;                                     % [K,K]

return ;

end
% -------------------------------------------------------------------------------- __END__
