function HX = HX_outs( hotst , coldst , dTmin , reversehot = 0 )
%
% Calculates the maximum HX from streams inlet conditions and a given minimum approach.
%
% Arguments: hotst,coldst   = streams matrix, 1st column T [K], 2nd column qs [e.g.,kW]
%                             starting at q=0 and q-sorted; qs > 0: cold , qs < 0: hot .
%                             If just two rows stream is assumed constant mCp.
%                             First T of every stream is the entry one.
%            dTmin          = Minimun allowed T approach between streams. [K]
%            [reversehot]   = 0/1 , flag reverse hot stream TvsH curve. Default: 0 .
% Returns  : HX = matrix containing ... 
%            Thout   Thin   = Hot outlet , Hot inlet Ts   [K]
%            Tcin    Tcout  = Cold inlet , Cold outlet Ts [K]
%            duty    nhs    = Duty [kW] , number of hot stream points
%            T1h     H1h    = T vs H hot curve points H = 0 based
%                ...
%            T1c     H1c    = T vs H cold curve points H = 0 based
%                ...
%
% Copyright (c) Fidel Mato & UVa 2019
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Heat integration, Heat exchanger
%
% [Note: kW are used as an alias for any thermal flow unit and K for any T unit.]

% Transforming streams in [Ts dHs ] format to hix format streams [ T1 T2 dH 0 ] :
strs     = [ TsdHs_to_strs( hotst ) ; TsdHs_to_strs( coldst )  ] ; % in hix format

casc     = cascade( strs , dTmin )                                          ; % [K,kW] 
Hlastc   = coldst( end , 2 ) - casc( 1 , 2 )                                ; % [kW] 
Tcout    = interp1( coldst( : , 2 ) , coldst( : , 1 ) , Hlastc , 'linear' ) ; % [K]
Hlasth   = hotst( end , 2 ) + casc( end , 2 )                               ; % [kW]
Thout    = interp1( hotst( : , 2 ) , hotst( : , 1 ) , Hlasth , 'linear'   ) ; % [K]

% ------------------------------------------- Cutting the tail of the streams
HXhotst  = hotst( 1 , : )                            ;     % [K,kW] matrix
for( k = 2 : length( hotst( : , 1 ) ) )
    if( hotst( k , 2 ) < Hlasth )
        HXhotst  = [ HXhotst ; [ Thout , Hlasth ] ]  ;     % [K,kW] matrix
        break                                        ;
    end
        HXhotst  = [ HXhotst ; hotst( k , : ) ]      ;     % [K,kW] matrix
end
HXcoldst  = coldst( 1 , : )                          ;     % [K,kW] matrix
for( k = 2 : length( coldst( : , 1 ) ) )
    if( coldst( k , 2 ) > Hlastc )
        HXcoldst  = [ HXcoldst ; [ Tcout , Hlastc ] ] ;    % [K,kW] matrix
        break ;
    end
        HXcoldst  = [ HXcoldst ; coldst( k , : ) ]    ;    % [K,kW] matrix
end

nhs      = length( HXhotst( : , 1 ) )                 ;     % [] n hot stream points

Thin     = hotst( 1 , 1 )  ;                               % [K]
Tcin     = coldst( 1 , 1 ) ;                               % [K]
duty     = Hlastc          ;                               % [kW] 

if( reversehot == 1 )
    HXhotst( : , 2 ) = HXhotst( : , 2 ) - HXhotst( end , 2 ) ;
end

HX       = ...
[ [ Thout   Thin
    Tcin    Tcout
    duty    nhs      ]   ;
    HXhotst            ;
    HXcoldst         ] ;

return ;

end
% -------------------------------------------------------------------------------- __END__
