function mindT = mindT_in_HX_curves(    hotst  , hstfrac , Thout , Thin  , ...
                                        coldst , cstfrac , Tcin  , Tcout )
% Calculates mimimun difference of T in a HX from T vs. q hot&cold stream curves
% Arguments: hotst,coldst   = streams matrix, 1st column T [K], 2nd column qs [e.g.,kW]
%                             starting at q=0 and q-sorted; qs > 0: cold , qs < 0: hot .
%                             If just two rows stream is assumed constant mCp.
%            hst,cstfrac    = flowrate fraction of stream involved in this HX. []
%            T[h|c][in|out] = Hot|Cold,inlet|outlet temperatures.  -1 if unknow.
%                             If cold side Ts != -1 and hot side Ts == -1 , the maximun
%                             duty up-in-T is calculated until dT == dTmin or one
%                             stream is exhausted; and viceversa. [K]
%            duty           = same units that qs. -1 if unknow. if != -1 the calculation
%                             proceeds till max. duty is completed or dTmin is found. [kW]
%            dTmin          = Minimun allowed T approach between streams. [K]
%            plot           = flag if != 0, plot HX T vs. duty. Else, don't.
% Returns  : mindT          = mimimun difference of T [K]

%%%% Returns  : HX = matrix containing ... 
%%%%            Thout   Thin   = Hot outlet , Hot inlet Ts   [K]
%%%%            Tcin    Tcout  = Cold inlet , Cold outlet Ts [K]
%%%%            duty    dTln   = Duty [kW]  , logarithmic mean of extreme T differences [K]
%%%%            cstfrac hstfrac= cold, hot stream fraction involved in this HX. []
%%%%            coldT   hotdT  = T differences in the cold, hot side [K]
%%%%            mindT   maxdT  = Minimum and maximum T difference [K]

% Copyright (c) Fidel Mato & UVa 2018
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Heat integration, Heat exchanger

% [Note: kW are used as an alias for any thermal flow unit.]

%nsteps   = 50000 ;
nsteps   =  1000 ;

Ths      = hotst( : , 1 )          ;                       % [K]
Hhs      = hotst( : , 2 )*hstfrac  ;                       % [kW]
Tcs      = coldst( : , 1 )         ;                       % [K]
Hcs      = coldst( : , 2 )*cstfrac ;                       % [kW]

Hhout    = interp1( Ths , Hhs , Thout ) ;                % [kW]
Hcin     = interp1( Tcs , Hcs , Tcin  ) ;                % [kW]
Hhin     = interp1( Ths , Hhs , Thin )  ;                % [kW]
Hcout    = interp1( Tcs , Hcs , Tcout ) ;                % [kW]

if( Hhin - Hhout <= Hcout - Hcin )
    H1 = Hcin  ;  H2 = Hcout ; incH = ( Hcout - Hcin )/nsteps ;
else
    H1 = Hhout ;  H2 = Hhin  ; incH = -( Hhout - Hhin )/nsteps ;
end

mindT  = 1e3   ;
maxdT  = 0     ;
for( H = H1 : incH : H2 )
    duty = H - H1                              ;       % [kW]
    Th   = interp1( Hhs , Ths , Hhout + duty ) ;       % [K]
    Tc   = interp1( Hcs , Tcs , Hcin + duty )  ;       % [K]
    dT   = Th - Tc                             ;       % [K]
    %fprintf( '%8.3f %8.3f %10.2f %6.2f\n' , Th , Tc , duty , dT ); % DEBUG
    if( dT < mindT ) mindT = dT ; end
    if( dT > maxdT ) maxdT = dT ; end
end
   
return ;

end
% -------------------------------------------------------------------------------- __END__
