function dSid_O2 = AL_dSid_O2( T1 , T2 )
%
% AL_dSid_O2 - Oxygen ideal entropy difference using Aly&Lee equation.
%
%   Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
%   Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
%
%   call  : AL_dSid_O2( T1 , T2 ) where [ T1, T2 ] = [ K , K ]
%   return: dSid_O2 in [ J/mol/K ]

% ---------------------------------------------------------- O2 (273.15-1500 K) Parameters
% From Aly&Lee_1981 Table 1, p 174
% B_O2  =     6.96302*4.1840 ;                               % [cal/mol/K => J/mol/K]
% C_O2  =     2.40013*4.1840 ;                               % [cal/mol/K => J/mol/K]
% D_O2  =  2522.05           ;                               % [K]
% E_O2  =     2.21752*4.1840 ;                               % [cal/mol/K => J/mol/K]
% F_O2  =  1154.15           ;                               % [K]
% G_O2  =     9.19749*4.1840 ;                               % [cal/mol/K => J/mol/K]

B_O2  =    29.13327568 ;                                     % [J/mol/K]
C_O2  =    10.04214392 ;                                     % [J/mol/K]
D_O2  =  2522.05       ;                                     % [K]
E_O2  =     9.27810368 ;                                     % [J/mol/K]
F_O2  =  1154.15       ;                                     % [K]
G_O2  =    38.48229816 ;                                     % [J/mol/K]

B = B_O2  ; C = C_O2  ; D = D_O2  ; E = E_O2  ; F = F_O2  ; G = G_O2  ;

% ---------------------------------------------------------------------------- Calculation
T = T2 ;                                                   % [K]
dSid_O2 = B*log( T ) + C*( D/T*coth( D/T ) - log( sinh( D/T ) ) ) - ...
            E*( F/T*tanh( F/T ) - log( cosh( F/T ) ) ) ;                % [J/mol/K]

T = T1 ;                                                   % [K]
dSid_O2 =  dSid_O2 - ( B*log( T ) + C*( D/T*coth( D/T ) - log( sinh( D/T ) ) ) - ...
            E*( F/T*tanh( F/T ) - log( cosh( F/T ) ) ) ) ;              % [J/mol/K]

return ;
