function params = SRK_mix_parameters( T , P , composition , props , alphafun , mixrule )
% Calculates Soave-Redlich-Kwong mixture parameters.
% Arguments: T , P = [ K , bar ]
%            composition = molar fraction mixture composition vector.
%            props = Property matrix, one column per component, containing -at least-
%                    Tc [K] , Pc [bar] and Pitzer's w [] in the first three rows.  
%            alphafun = string containing the alpha function type to use , among
%                       'orig'||'SRK' , 'Ledanois' , 'orig+BM' , 'Ledanois+BM'
%            mixrule  = string containing the mixing rule type to use, among : 'Virial'
% Returns  : params   = matrix containing SRK mixture parameters 
%                        [ Amix Bmix   0  0  ...           []
%                          amix bmix   0  0  ...           [bar*L^2/mol^2]
%                          B1   B2    ...    Bn            [] 
%                          A11  A12   ...    A1n           [] cross coefficients
%                          A21  A22   ...    A2n           [] cross coefficients
%                          ...  ...   ...    ...           [] cross coefficients
%                          An1  An2   ...    Ann  ]        [] cross coefficients

% Copyright (c) Fidel Mato & UVa 2016
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Parameters, Cubic EOS , Soave Redlich Kwong

R        = 0.08314459848 ;                                 % [bar*L/mol/K]

[ rows , ncomp ] = size( props ) ;                         % ncompounds

as       = [  ] ;                                          % [bar*L^2/mol^2]

Tcs      = props( 1 , : ) ;                                % [K]
Pcs      = props( 2 , : ) ;                                % [bar]
ws       = props( 3 , : ) ;                                % []

acs      = 0.427480*R^2* Tcs.^2 ./ Pcs ;                   % [bar*L^2/mol^2]
bs       = 0.086640*R*Tcs ./ Pcs       ;                   % [L/mol]
Bs       = bs.*P/R/T                   ;                   % []

for( k = 1 : ncomp )   % To be vectorized
                       % alphas = arrayfun( SRK_1C_alpha( alphafun , Tcs , ws ) ) 
    Tc = Tcs( k ) ;                                        % [K]
    w  =  ws( k ) ;                                        % []
    Tr = T/Tc     ;                                        % []

    [ alpha m ] = SRK_1C_alpha( alphafun , Tr , w ) ;      % []
    as( end + 1 ) = alpha*acs( k )               ;         % [bar*L^2/mol^2]

end

as       = repmat( as , ncomp , 1 ) ;                      % [bar*L^2/mol^2]
aijs     = ( as.*as' ).^0.5         ;                      % []
Aijs     = aijs*P/R^2/T^2           ;                      % [] 

amix     = repmat( composition , ncomp , 1 ) ;             % [mol.frac]
amix     = sum( sum( amix.*amix'.*aijs ) )   ;             % [bar*L^2/mol^2]
bmix     = sum( composition.*bs )            ;             % [L/mol]

Amix     = amix*P/R^2/T^2                    ;             % []
Bmix     = bmix*P/R/T                        ;             % []

params   = [ Amix Bmix zeros( ncomp - 2 ) ;                % []
             amix bmix zeros( ncomp - 2 ) ;                % [bar*L^2/mol^2]
             Bs                           ;                % []
             Aijs                           ] ;            % []

end
% -------------------------------------------------------------------------------- __END__
