function Hres = PR_enth_res( T , P , z , x_O2 , x_N2 , x_CO2 , x_H2O )
%
% PR_enth_res - Residual enthalpy calculation using Peng-Robinson EoS
% Just for { O2 , N2 , CO2 , H2O } mixtures
% Call: [T,P,z,x_O2,x_N2,x_CO2,x_H2O] = [ K , Pa , dimless , m.f. , m.f. , m.f. , m.f. ]
% Return : Hres = [ J/mol ]

% ----------------------------------------------------------------------------- Properties
R = 8.3144621     ;                                        % [J/mol/K]

Tc_O2  = 154.581  ;                                        % [K]
Pc_O2  = 5.043e6  ;                                        % [Pa]
w_O2   = 0.0222   ;                                        % [dimless] Pitzer ac. fac.
MM_O2  = 31.999   ;                                        % [g/mol]

Tc_N2  = 126.192  ;                                        % [K]
Pc_N2  = 3.3958e6 ;                                        % [Pa]
w_N2   = 0.0372   ;                                        % [dimless] Pitzer ac. fac.
MM_N2  = 28.013   ;                                        % [g/mol]

Tc_CO2 = 304.1282 ;                                        % [K]
Pc_CO2 = 7.3773e6 ;                                        % [Pa]
w_CO2  = 0.22394  ;                                        % [dimless] Pitzer ac. fac.
MM_CO2 = 44.01    ;                                        % [g/mol]

Tc_H2O = 647.096  ;                                        % [K]
Pc_H2O = 22.064e6 ;                                        % [Pa]
w_H2O  = 0.3443   ;                                        % [dimless] Pitzer ac. fac.
MM_H2O = 18.015   ;                                        % [g/mol]
	
Tcs    = [ Tc_O2 ; Tc_N2 ; Tc_CO2 ; Tc_H2O ] ;             % [K]
Pcs    = [ Pc_O2 ; Pc_N2 ; Pc_CO2 ; Pc_H2O ] ;             % [Pa]
ws     = [ w_O2  ; w_N2  ; w_CO2  ; w_H2O  ] ;             % [dimless]
MMs    = [ MM_O2 ; MM_N2 ; MM_CO2 ; MM_H2O ] ;             % [g/mol]
xs     = [ x_O2  ; x_N2  ; x_CO2  ; x_H2O  ] ;             % [m.f.]

% --------------------------------- Binary Interaction Parameters
% 1: O2 ; 2: N2 ; 3: CO2 ; 4: H2O 

k12        = zeros( 4 , 4 ) ;

k12( 1 , 2 )  = -0.10458767 ;                              % Joao    ¿Error?
k12( 2 , 1)   = -0.10458767 ;                              % Joao    ¿Error?
k12( 1 , 2 )  = -0.0119     ;                              % Yoana
k12( 2 , 1 )  = -0.0119     ;                              % Yoana

k12( 1 , 3 )  = -0.10458767 ;                              % Joao    ¿Error?
k12( 3 , 1 )  = -0.10458767 ;                              % Joao    ¿Error?
k12( 1 , 3 )  =  0          ;                              % Yoana
k12( 3 , 1 )  =  0          ;                              % Yoana

k12( 1 , 4 )  = -0.7575008  ;                              % Joao
k12( 4 , 1 )  = -0.7575008  ;                              % Joao
k12( 1 , 4 )  =  0          ;                              % Yoana
k12( 4 , 1 )  =  0          ;                              % Yoana

k12( 2 , 3 )  =  0          ;                              % Joao
k12( 3 , 2 )  =  0          ;                              % Joao
k12( 2 , 3 )  = -0.017      ;                              % Yoana
k12( 3 , 2 )  = -0.017      ;                              % Yoana

k12( 2 , 4 )  =  0.4788     ;                              % Joao
k12( 4 , 2 )  =  0.4788     ;                              % Joao
k12( 2 , 4 )  =  0          ;                              % Yoana
k12( 4 , 2 )  =  0          ;                              % Yoana

k12( 3 , 4 )  =  0.12       ;                              % Yoana+Joao
k12( 4 , 3 )  =  0.12       ;                              % Yoana+Joao

l12           =  0          ;

% --------------------------------------------------------------- residual enthalpy at T,P

Trs = T./Tcs ;                                             % [dimless] Reduc. Ts (vector)
Prs = P./Pcs ;                                             % [dimless] Reduc. Ps (vector)

% --------------------------------- Peng-Robinson Pure Compound Parameters
ms    = 0.37464 + 1.54226.*ws - 0.26992*ws.^2 ;            % [dimless]
alfas = (1 + ms.*(1 - Trs.^.5)).^2 ;                       % [dimless]
acs   = 0.457235*R^2*Tcs.^2./Pcs ;                         % [J*m^3/mol^2]=[Pa*(m^3/mol)^2]
bcs   = 0.077796*R.*Tcs./Pcs ;                             % [m^3/mol]

% ----------------------------------------------------------- Mixing Rules
ncomp = length(xs) ;                                        % Number of compounds
for i = 1:ncomp
    for j = 1:ncomp
       as(i,j) = (1 - k12(i,j))*(alfas(i)*acs(i)*alfas(j)*acs(j))^0.5 ;  % [J*m^3/mol^2]=[Pa*(m^3/mol)^2]
       bs(i,j) = (1 - l12)*(bcs(i) + bcs(j))/2 ;           % [m^3/mol]
    end
end

aM = 0 ;                                                   % [J*m^3/mol^2]=[Pa*(m^3/mol)^2]
bM = 0 ;                                                   % [m^3/mol]
for i = 1:ncomp
   for j = 1:ncomp
      aM = aM + xs(i)*xs(j)*as(i,j);                       % [J*m^3/mol^2]=[Pa*(m^3/mol)^2]
      bM = bM + xs(i)*xs(j)*bs(i,j);                       % [m^3/mol]
   end
end

A = aM*P/(R*T)^2 ;                                         % [J*m^3/mol^2]=[Pa*(m^3/mol)^2]
B = bM*P/(R*T)   ;                                         % [m^3/mol]

DM = 0;
for i = 1:ncomp
   for j = 1:ncomp
        DM = DM + xs(i)*xs(j)*ms(j)*(1 - k12(i,j))*(as(i)*alfas(i))^0.5*(as(j)*Trs(j))^0.5 ; % []
   end
end

%Hres = R*T*(1 - z + (A/(2.828*bM))*(1 + DM/aM)*log((z + 2.414*bM)/(z - 0.414*bM)));  % [J/mol]
Hres = R*T*(1 - z + (A/(2.828*B))*(1 + DM/aM)*log((z + 2.414*B)/(z - 0.414*B)));  % [J/mol]
return ;


