function Psat= SRK_1C_Psat( T , Tc , Pc ,w )

% Calculates saturation P for a T using the Soave-Redlich-Kwong EoS
% Arguments: ( T , Tc , Pc , w ) = [ K , K , bar , dimless ]
% Returns  : Psat [ bar ] or error
% Errors   : -1 => complex roots found by solver
%          : -2 => supercritical conditions

% Copyright (C) 2016 Fidel Mato
% Author: Fidel Mato <fidel@iq.uva.es>
% Keywords: saturation pressure, vapor pressure , EOS , Soave Redlich Kwong
% Maintainer: Fidel Mato <fidel@iq.uva.es>


R          = 0.08314459848 ;                               % [bar*L/mol/K]
precission = 1e-5 ;                                        % [dimless]
dP         = 1e-12 ;                                        % [bar]

Tr       = T/Tc                 ;                          % [dimless]

% Checking supercritical conditions:
if( T > Tc )
    Psat = -2 ;
    return    ;
end

ac       = 0.427480*R^2*Tc^2/Pc   ;                        % [bar*L^2/mol^2] SRK
b        = 0.086640*R*Tc/Pc       ;                        % [L/mol]         SRK
alpha    = SRK_1C_alpha( Tr , w ) ;                        % [dimless]
a        = ac*alpha               ;                        % [bar*L^2/mol^2]

% ---------------------------------------------- P estimation ( from SRK 1st derivative)
% V^4 + (2*b - 2*a*alfa/R/T)*V^3 + (b^2 + 3*a*alfa*b/R/T)*V^2 - a*alfa*b^3/R/T == 0
coefs = [ R*T , +(2*b*R*T - 2*a) , +(b^2*R*T + 3*a*b) , 0 , -a*b^3 ]   ;        
Vmax  = max( roots( coefs ) ) ;                            % [L/mol]
Pmax  = R*T/( Vmax - b ) - a/Vmax/( Vmax + b ) ;           % [bar]
P     = Pmax - 1e-6 ;                                     % [bar]

while( 1 == 1 )

    P = P - dP/2 ;                                         % [bar]
    [ Zv Zl ] = SRK_1C_compress_factors( T , P , Tc , Pc , w ) ; % [dimless]
    if ~( isreal( Zv ) && isreal( Zl  ))                   % if any not real...
        fprintf('\nFunction %s error: Complex root\n\n' , mfilename() ); % explain...
        Psat = -1 ;   
        return    ;
    end
    Pr    = P/Pc                   ;                       % [dimless]
    A     = 0.42748*alpha*Pr/Tr^2  ;                       % [dimless]
    B     = 0.08664*Pr/Tr          ;                       % [dimless]
    phiv  = exp( Zv - 1 - log( Zv - B ) - A/B*log( 1 + B/Zv ) ) ; % [dimless]
    phil  = exp( Zl - 1 - log( Zl - B ) - A/B*log( 1 + B/Zl ) ) ; % [dimless]

    ydec  = 1 - (phiv/phil)^3 ;                            % [dimless]
    
    P = P + dP/2 + dP/2 ;                                  % [bar]
    [ Zv Zl ] = SRK_1C_compress_factors( T , P , Tc , Pc , w ) ; % [dimless]
    if ~( isreal( Zv ) && isreal( Zl  ))                   % if any not real...
        fprintf('\nFunction %s error: Complex root\n\n' , mfilename() ); % explain...
        Psat = -1 ;   
        return    ;
    end
    Pr    = P/Pc                   ;                       % [dimless]
    A     = 0.42748*alpha*Pr/Tr^2  ;                       % [dimless]
    B     = 0.08664*Pr/Tr          ;                       % [dimless]
    phiv  = exp( Zv - 1 - log( Zv - B ) - A/B*log( 1 + B/Zv ) ) ; % [dimless]
    phil  = exp( Zl - 1 - log( Zl - B ) - A/B*log( 1 + B/Zl ) ) ; % [dimless]

    yinc  = 1 - (phiv/phil)^3 ;                                % [dimless]
    
    P = P - dP/2 ;                                         % [bar]
    [ Zv Zl ] = SRK_1C_compress_factors( T , P , Tc , Pc , w ) ; % [dimless]
    if ~( isreal( Zv ) && isreal( Zl  ))                   % if any not real...
        fprintf('\nFunction %s error: Complex root\n\n' , mfilename() ); % explain...
        Psat = -1 ;   
        return    ;
    end
    Pr    = P/Pc                   ;                       % [dimless]
    A     = 0.42748*alpha*Pr/Tr^2  ;                       % [dimless]
    B     = 0.08664*Pr/Tr          ;                       % [dimless]
    phiv  = exp( Zv - 1 - log( Zv - B ) - A/B*log( 1 + B/Zv ) ) ; % [dimless]
    phil  = exp( Zl - 1 - log( Zl - B ) - A/B*log( 1 + B/Zl ) ) ; % [dimless]

    y  = 1 - (phiv/phil)^3 ;                            % [dimless]

    
    yerr  = abs( phiv - phil ) ;
    if( abs( phiv - phil ) < precission )
        break ;
    end

    yderiv = ( yinc - ydec )/dP ;                             % [1/bar]
    P      = P - y/yderiv    ;                             % [bar]
       
end
Psat = P ;                                                 % [bar]

end
% -------------------------------------------------------------------------------- __END__


















