function Psat = VDW_1C_Psat( T , Tc , Pc )
% Calculates saturation P for a T using the van der Waals EoS
% Arguments: ( T , Tc , Pc ) = [ K , K , bar ]
% Returns  : Psat [ bar ] if a saturation pressure is converged, or
%            -1           if no 2-phase condition (vapor/liquid only , i.e., 1 real root)

% Copyright (C) 2016 Fidel Mato
% Author: Fidel Mato <fidel@iq.uva.es>
% Keywords: saturation pressure, vapor pressure , EOS , Soave Redlich Kwong
% Maintainer: Fidel Mato <fidel@iq.uva.es>

% ----------------------------------------------------------------------------- Properties
R        = 0.08314459848  ;                                % [bar*L/mol/K]

% ------------------------------------------------------------------------- Specifications
precission = 1e-8         ;

% ---------------------------------------------------------------------------- Calculation
a     = 27*R^2*Tc^2/64/Pc ;                                % [bar*L^2/mol^2]
b     = R*Tc/8/Pc         ;                                % [L/mol]

% ------------------ Solver initialization:
Vmax     = max( roots( [ +R*T  -2*a  +4*a*b  -2*a*b^2 ] ) ) ; % [L/mol]
P        = R*T/( Vmax - b ) - a/Vmax^2 - 1e-8               ; % [bar] Estim. P

err   = 10 ;
while( err > precission  )

    % ---------------- Z polynomial:
    coefz = [ 1 -(b*P/R/T+1) a*P/R^2/T^2 -a*b*P^2/R^3/T^3 ] ; % [dimless]
    solsZ = roots(coefz) ;
    
    % ---------------- Fugacity coefficients:
    Zv    = solsZ(1);                                      % [dimless]
    Zl    = solsZ(3);                                      % [dimless]
    
    if ~(isreal(Zv) && isreal(Zl))                         % if any not real...
        fprintf('\nFunction %s error: Complex root\n\n' , mfilename() ); % explain...
        Psat = -1 ;
        return ;                                           % and exits
    end
    
    Vid = R*T/P;                                           % [L/mol]
    Vl    = Zl*Vid;                                        % [L/mol]
    Vv    = Zv*Vid;                                        % [L/mol]
    
    cfugl = exp( Zl - 1 - a/R/T/Vl - log( Zl*( 1 - b/Vl ) ) ) ; % [dimless]
    cfugv = exp( Zv - 1 - a/R/T/Vv - log( Zv*( 1 - b/Vv ) ) ) ; % [dimless]
    
    err   = abs( cfugl - cfugv ) ;
    
    % ---------------- new value for iteration:
    P     = P*cfugl/cfugv ;                                   % [bar]
        
end
Psat     = P ;                                             % [bar]


return ;



